Module dispatch

Module dispatch 

Shared dispatch layer for all network transports.

Pure helpers (build_server_message) live in reifydb_core::actors::server so both native transports and DST clients can share them. The async dispatch() / dispatch_subscribe() functions are the single entry points for native transport handlers.

Functions

dispatch
Dispatch a query/command/admin operation through the actor with interceptors.
dispatch_subscribe
Dispatch a subscribe operation through the actor with interceptors.