pub async fn connect_remote(
address: &str,
query: &str,
token: Option<&str>,
) -> Result<RemoteSubscription, RemoteSubscriptionError>Expand description
Connect to a remote node and create a subscription.
pub async fn connect_remote(
address: &str,
query: &str,
token: Option<&str>,
) -> Result<RemoteSubscription, RemoteSubscriptionError>Connect to a remote node and create a subscription.