pub fn convert_frames(frames: Vec<Frame>) -> Vec<ResponseFrame>Expand description
Convert database result frames to response frames.
This function converts the internal Frame type to the serializable
ResponseFrame type expected by clients.
pub fn convert_frames(frames: Vec<Frame>) -> Vec<ResponseFrame>Convert database result frames to response frames.
This function converts the internal Frame type to the serializable
ResponseFrame type expected by clients.