Application state shared across request handler.
This module provides the shared state that is passed to all HTTP and WebSocket handler, including the database engine and query configuration.
Structs
- AppState
- Shared application state passed to all request handler.
- State
Config - Configuration for query execution.