pub struct AppState { /* private fields */ }Expand description
Shared application state passed to all request handler.
This struct is cloneable and cheap to clone since StandardEngine uses
Arc internally. Each handler receives a clone of this state.
Example
ⓘ
let state = AppState::new(actor_system, engine, QueryConfig::default());
// In an axum handler:
async fn handle_query(State(state): State<AppState>, ...) {
let system = state.actor_system();
let engine = state.engine();
// ...
}Implementations
Sourceimpl AppState
impl AppState
Sourcepub fn new(
actor_system: ActorSystem,
engine: StandardEngine,
config: StateConfig,
) -> Self
pub fn new( actor_system: ActorSystem, engine: StandardEngine, config: StateConfig, ) -> Self
Create a new AppState with the given actor system, engine, and configuration.
Sourcepub fn actor_system(&self) -> ActorSystem
pub fn actor_system(&self) -> ActorSystem
Get a clone of the actor system.
This is cheap since ActorSystem uses Arc internally.
Sourcepub fn engine(&self) -> &StandardEngine
pub fn engine(&self) -> &StandardEngine
Get a reference to the database engine.
Sourcepub fn engine_clone(&self) -> StandardEngine
pub fn engine_clone(&self) -> StandardEngine
Get a clone of the database engine.
This is cheap since StandardEngine uses Arc internally.
Sourcepub fn config(&self) -> &StateConfig
pub fn config(&self) -> &StateConfig
Get a reference to the query configuration.
Sourcepub fn query_timeout(&self) -> Duration
pub fn query_timeout(&self) -> Duration
Get the query timeout from configuration.
Sourcepub fn request_timeout(&self) -> Duration
pub fn request_timeout(&self) -> Duration
Get the request timeout from configuration.
Sourcepub fn max_connections(&self) -> usize
pub fn max_connections(&self) -> usize
Get the maximum connections from configuration.